@@ -61,6 +61,7 @@ def start_app(app: str):
         os.path.join(GRPC_PATH, 'Generated'),
         os.path.join(GRPC_PATH, 'Server'),
         os.path.join(GRPC_PATH, 'Client'),
+        os.path.join(GRPC_PATH, 'Servicer'),
         os.path.join(INFRA_PATH, 'Repositories', app)
     ]
     
@@ -318,6 +319,7 @@ package {app.lower()};
 import "Common.proto";
 
 // gRPC Service
+{app}Service
     '''
 
     common_proto = '''
@@ -325,8 +327,8 @@ syntax = "proto3";
 
 package common;
 
-message Request { bytes data = 1; }
-message Response { string status=1; string message=2; bytes data=3; }
+message Request { string data = 1; }
+message Response { string status=1; string message=2; string data=3; }
 message Empty {}
 '''
     server = '''
@@ -339,6 +341,12 @@ async def serve():
     # Register each service
     # Code Here ...
 
+    # Register reflection
+    SERVICE_NAMES = (
+        Example.DESCRIPTOR.services_by_name['ExampleService'].full_name,
+        reflection.SERVICE_NAME # List of services exposed via gRPC reflection
+    )
+
     # Single port exposed
     server.add_insecure_port("[::]:50051")
 
@@ -373,8 +381,8 @@ class {app}Client:
         os.path.join(INFRA_PATH, 'Repositories', app, init_file): repository_init_content,
         os.path.join(INFRA_PATH, 'Repositories', app, f'{app}Repository.py'): repository_content,
         os.path.join(GRPC_PATH, 'Proto', 'Common.proto'): common_proto,
-        os.path.join(GRPC_PATH, 'Proto', f'{app}Service.proto'): proto_app_content,
-        os.path.join(GRPC_PATH, 'Server', 'Server.py'): server,
+        os.path.join(GRPC_PATH, 'Proto', f'{app}.proto'): proto_app_content,
+        os.path.join(GRPC_PATH, 'Server', init_file): server,
         os.path.join(GRPC_PATH, 'Client', f'{app}Client.py'): grpc_client
     }
     for file_path in files:
@@ -407,7 +415,7 @@ def serve(port: int):
         logger.error(f'{Message.SERVER_NETWORK_ACCESS_ERROR_MSG}: {e}')
 
 
-@cli.command()
+@cli.command("clean-redis")
 @click.argument('redis_env')
 async def clean_redis(redis_env: str):
     try:
@@ -433,13 +441,19 @@ def proto_files(name: str):
     proto_path = os.path.join(proto_dir, f"{name}Service.proto")
     common_path = os.path.join(proto_dir, "Common.proto")
 
+    common_py = os.path.join(gen_dir, "Common_pb2.py")
+    common_grpc_py = os.path.join(gen_dir, "Common_pb2_grpc.py")
+
+    proto_files = [proto_path]
+    if not (os.path.exists(common_py) and os.path.exists(common_grpc_py)):
+        proto_files.append(common_path)
+
     cmd = [
         "python", "-m", "grpc_tools.protoc",
         f"-I={proto_dir}",
         f"--python_out={gen_dir}",
         f"--grpc_python_out={gen_dir}",
-        proto_path,
-        common_path
+        *proto_files
     ]
 
     subprocess.run(" ".join(cmd), shell=True, check=True)
